/**
 * List repository for an organization.
 * @function listOrgRepo
 * @param {string} name - Name of organization.
 * @param {function} callback - Callback when done.
 */

"use strict";

const _apiRequest = require('./_api_request'),
    async = require('async'),
    argx = require('argx');

const MAX_COUNT = 100;

/** @lends listOrgRepo */
function listOrgRepo(name, options, callback) {
    let args = argx(arguments);
    callback = args.pop('function') || argx.noop;
    options = args.pop('object') || {};
    let page = 1,
        found = [];

    async.whilst(
        () => page == 1 || (found === MAX_COUNT * (page - 1)),
        (callback) => {
            let pathname = `/orgs/${name}/repos?per_page=${MAX_COUNT}&page=${page}`;
            _apiRequest(pathname, (err, res, body) => {
                if (err) {
                    callback(err);
                } else {
                    let success = res.statusCode == 200;
                    if (success) {
                        let data = JSON.parse(body).map(listOrgRepo.parse);
                        found = found.concat(data);
                        setTimeout(()=> {
                            callback(null);
                            page += 1;
                        }, 100);
                    } else {
                        callback(new Error('Request failed with status: ' + res.statusCode));
                    }
                }
            });
        }, (err) => callback(err, found));
}
listOrgRepo.parse = function parse(data) {
    return {
        name: data.name,
        full_name: data.full_name,
        private: data.private,
        description: data.description,
        url: data.url,
        fork: data.fork
    };
};

module.exports = listOrgRepo;
